#ifndef __RECONFIGURE_H__
#define	__RECONFIGURE_H__

#include <time.h>

int    SetConfigFileUpdateInterval(int interval);
int    isTimeForRereadConfig(time_t time);
void   GetConfigDir(void);
int    ReadConfig(void);

#endif /* __RECONFIGURE_H__ */
